@@ -1,7 +1,7 @@
 #ifndef QHIMDFORMATDIALOG_H
 #define QHIMDFORMATDIALOG_H
 
-#include <QtGui/QDialog>
+#include <QDialog>
 
 namespace Ui {
     class QHiMDFormatDialog;
